@@ -50,7 +50,9 @@ wfs_api <- function(base.url = NULL, queries) {
     stop("base.url = NULL. Please input a valid WFS url")
   }
   
-  if (!grepl("^http", base.url)) stop("Invalid base URL")
+  if (!grepl("^http", base.url)) {
+    stop("Invalid base URL")
+  }
   
   # Set the user agent
   ua <- httr::user_agent("https://github.com/rOpenGov/helsinki")
@@ -65,7 +67,7 @@ wfs_api <- function(base.url = NULL, queries) {
   # See function help for more details ________________________________________
   try_GET <- function(x, ...) {
     tryCatch(
-      GET(url = x, httr::timeout(10), ...),
+      GET(url = x, httr::timeout(20), ...),
       error = function(e) conditionMessage(e),
       warning = function(w) conditionMessage(w)
     )
